==> release.12.2.28.1.tgz: cgi-cpn/lib_bd.pm <==
#!/usr/bin/perl

# --------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# --------------------------------------------------------------
# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# funciones para manejo de portadas
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ---------------------------

use strict;
use utf8;
package lib_bd;

# ---------------------------------------------------------------
# por defecto conecta a la bd configurada a prontus
# parámetros opcionales: $nom_bd, $server_bd, $user_bd, $pwd_bd.
sub conectar_prontus_bd {
    my ($nom_bd, $server_bd, $user_bd, $pwd_bd) = @_;
    # si no hay datos es una conexion a la bd por defecto de este prontus
    if ($nom_bd eq '') {
    # revisamos si ya se hizo la conexion antes o no para reutilizarla
        if (!ref($prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}) or $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->ping != 1) {
            # conexion nueva
            $nom_bd    = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'NOM_BD'};
            $server_bd = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'SERVER_BD'};
            $user_bd   = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'USER_BD'};
            $pwd_bd    = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PWD_BD'};

            my ($msg_ret);
            $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID} = DBI->connect_cached("DBI:mysql:$nom_bd:$server_bd", $user_bd, $pwd_bd, {'PrintError' => 1, mysql_enable_utf8mb4 => 1});
            if ($DBI::err) {
                $msg_ret = "No es posible conectar con base de datos Prontus MySQL. Cod[$DBI::err][$DBI::errstr]";
            } else {
                $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->{mysql_auto_reconnect} = 1;    # para evitar los MySQL server has gone away
                $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->do(qq{SET NAMES 'utf8mb4';});
                $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->do("SET sql_mode=(SELECT REPLACE(\@\@sql_mode,'ONLY_FULL_GROUP_BY',''));");
            }
            # my $database_name = $base->get_info( 17 ); # nombre del motor
            # my $database_version = $base->get_info( 18 ); # version del motor
            # print STDERR "Motor BD: $database_name $database_version\n";

            return ($prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}, $msg_ret);
        } else {
            #ya existe la conexion
            return ($prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}, '');
        }
    } else {
        # conexion nueva no es a la bd de este prontus
        my ($msg_ret, $base);
        $base = DBI->connect("DBI:mysql:$nom_bd:$server_bd", $user_bd, $pwd_bd, {'PrintError' => 1, mysql_enable_utf8mb4 => 1});
        if ($DBI::err) {
            $msg_ret = "No es posible conectar con base de datos Prontus MySQL. Cod[$DBI::err][$DBI::errstr]";
        } else {
            $base->{mysql_auto_reconnect} = 1;    # para evitar los MySQL server has gone away
            $base->do(qq{SET NAMES 'utf8mb4';});
            $base->do("SET sql_mode=(SELECT REPLACE(\@\@sql_mode,'ONLY_FULL_GROUP_BY',''));");
        }

        return ($base, $msg_ret);
    }
}

1;

==> release.12.3.1.2.tgz: cgi-cpn/lib_bd.pm <==
#!/usr/bin/perl

# --------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# --------------------------------------------------------------
# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# funciones para manejo de portadas
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ---------------------------

use strict;
use utf8;
package lib_bd;

# ---------------------------------------------------------------
# por defecto conecta a la bd configurada a prontus
# parámetros opcionales: $nom_bd, $server_bd, $user_bd, $pwd_bd.
sub conectar_prontus_bd {
    my ($nom_bd, $server_bd, $user_bd, $pwd_bd) = @_;
    # si no hay datos es una conexion a la bd por defecto de este prontus
    if ($nom_bd eq '') {
    # revisamos si ya se hizo la conexion antes o no para reutilizarla
        if (!ref($prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}) or $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->ping != 1) {
            # conexion nueva
            $nom_bd    = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'NOM_BD'};
            $server_bd = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'SERVER_BD'};
            $user_bd   = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'USER_BD'};
            $pwd_bd    = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PWD_BD'};

            my ($msg_ret);
            $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID} = DBI->connect_cached("DBI:mysql:$nom_bd:$server_bd", $user_bd, $pwd_bd, {'PrintError' => 1, mysql_enable_utf8mb4 => 1});
            if ($DBI::err) {
                $msg_ret = lib_lang::get_message('global_prontus_connect_bd_error') ." Cod[$DBI::err][$DBI::errstr]";
            } else {
                $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->{mysql_auto_reconnect} = 1;    # para evitar los MySQL server has gone away
                $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->do(qq{SET NAMES 'utf8mb4';});
                $prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}->do("SET sql_mode=(SELECT REPLACE(\@\@sql_mode,'ONLY_FULL_GROUP_BY',''));");
            }
            # my $database_name = $base->get_info( 17 ); # nombre del motor
            # my $database_version = $base->get_info( 18 ); # version del motor
            # lib_stdlog::print_err("Motor BD: $database_name $database_version\n");

            return ($prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}, $msg_ret);
        } else {
            #ya existe la conexion
            return ($prontus_varglb::BD_CONN{$prontus_varglb::PRONTUS_ID}, '');
        }
    } else {
        # conexion nueva no es a la bd de este prontus
        my ($msg_ret, $base);
        $base = DBI->connect("DBI:mysql:$nom_bd:$server_bd", $user_bd, $pwd_bd, {'PrintError' => 1, mysql_enable_utf8mb4 => 1});
        if ($DBI::err) {
            $msg_ret = lib_lang::get_message('global_prontus_connect_bd_error') . " Cod[$DBI::err][$DBI::errstr]";
        } else {
            $base->{mysql_auto_reconnect} = 1;    # para evitar los MySQL server has gone away
            $base->do(qq{SET NAMES 'utf8mb4';});
            $base->do("SET sql_mode=(SELECT REPLACE(\@\@sql_mode,'ONLY_FULL_GROUP_BY',''));");
        }

        return ($base, $msg_ret);
    }
}

1;
